| Copyright | (c) 2015-2025 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+gogol@gmail.com> Toni Cebrián <toni@tonicebrian.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | GHC2021 |
Gogol.VideoIntelligence.Videos.Annotate
Contents
Description
Performs asynchronous video annotation. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains AnnotateVideoProgress (progress). Operation.response contains AnnotateVideoResponse (results).
See: Cloud Video Intelligence API Reference for videointelligence.videos.annotate.
Synopsis
- type VideoIntelligenceVideosAnnotateResource = "v1p3beta1" :> ("videos:annotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoRequest :> Post '[JSON] GoogleLongrunning_Operation))))))))
- data VideoIntelligenceVideosAnnotate = VideoIntelligenceVideosAnnotate {}
- newVideoIntelligenceVideosAnnotate :: GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoRequest -> VideoIntelligenceVideosAnnotate
Resource
type VideoIntelligenceVideosAnnotateResource = "v1p3beta1" :> ("videos:annotate" :> (QueryParam "$.xgafv" Xgafv :> (QueryParam "access_token" Text :> (QueryParam "callback" Text :> (QueryParam "uploadType" Text :> (QueryParam "upload_protocol" Text :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoRequest :> Post '[JSON] GoogleLongrunning_Operation)))))))) Source #
A resource alias for videointelligence.videos.annotate method which the
VideoIntelligenceVideosAnnotate request conforms to.
Constructing a Request
data VideoIntelligenceVideosAnnotate Source #
Performs asynchronous video annotation. Progress and results can be retrieved through the google.longrunning.Operations interface. Operation.metadata contains AnnotateVideoProgress (progress). Operation.response contains AnnotateVideoResponse (results).
See: newVideoIntelligenceVideosAnnotate smart constructor.
Constructors
| VideoIntelligenceVideosAnnotate | |
Fields
| |
Instances
newVideoIntelligenceVideosAnnotate Source #
Arguments
| :: GoogleCloudVideointelligenceV1p3beta1_AnnotateVideoRequest | Multipart request metadata. See |
| -> VideoIntelligenceVideosAnnotate |
Creates a value of VideoIntelligenceVideosAnnotate with the minimum fields required to make a request.